# Demo

This directory contains demonstration notebooks for setting up various experiments that can be run with the pylabnet software.

**When developing new functionality for the package, please add and test demo notebooks (including auxiliary notebooks for logging + equipment servers) before merging your changes into the master branch!**

The idea is that the notebooks in the demo folder can be copied into a new "experiment" directory on a local machine and used immediately for experiments. If substantial changes are then made to the notebook, please update the relevant demo diretory on github so the most up-to-date, functional notebooks are accessible to all users.
